@@ -1,7 +1,7 @@
 # Copyright 2013, Sean B. Palmer
 # Source: http://inamidst.com/saxo/
 
-version = "0.1.003"
+version = "0.1.004"
 # WARNING: If updating anything before this message,
 # change the offset in setup.py
 
@@ -69,6 +69,22 @@ def communicate(command, args, base=None):
     client.send(command + b" " + base64.b64encode(pickled) + b"\n")
     client.close()
 
+# TODO: Can't call this saxo.database, because the import sets that attribute
+def db(name=None):
+    import os
+
+    # Save PEP 3122!
+    if "." in __name__:
+        from .database import Database
+    else:
+        from database import Database
+
+    if name is None:
+        base = os.environ["SAXO_BASE"]
+        name = os.path.join(base, "database.sqlite3")
+
+    return Database(name)
+
 # TODO: priority?
 def event(command="*", synchronous=False):
     def decorate(function):
